<?php
/**
 * Item Model for JMyLife Component
 *
 * @package    JMyLife
 * @subpackage Components
 * @version    1.0.16
 * @copyright  2009-2010 Jeff Channell
 * components/com_jmylife/models/item.php
 * @license

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */
// No direct access
defined( '_JEXEC' ) or die( 'Restricted access' );
// imports
jimport( 'joomla.application.component.model' );

/**
 * Item Model
 *
 * @package    JMyLife
 * @subpackage Components
 */
class JmylifeModelItem extends JModel
{
	/**
	 * data
	 * @var stdClass
	 */
	var $_data = null;

	/**
	 * Items total - for pagination
	 * @var integer
	 */
	var $_total = null;

	/**
	 * Pagination object
	 * @var object
	 */
	var $_pagination = null;

	/**
	 * contructor
	 */
	function __construct()
	{
		parent::__construct();
		$_JMLConfig = JmylifeConfiguration::getInstance();
		// J!1.6 doesn't use mainframe
		$appl =& JFactory::getApplication();
		//$params	=& $appl->getParams( 'com_jmylife' );

		// Get pagination request variables
		$limit = $_JMLConfig->getInt( 'page_limit', 10 );
		$limitstart = JRequest::getVar( 'limitstart', 0, '', 'int' );

		// In case limit has been changed, adjust it
		$limitstart = ( $limit != 0 ? ( floor( $limitstart / $limit ) * $limit ) : 0 );

		$this->setState( 'limit', $limit );
		$this->setState( 'limitstart', $limitstart );
  }

	/**
	 * gets list (override for long word handling)
	 * @return object list
	 * @since 1.0.4
	 * @renamed 1.0.5
	 */
	function _jmlGetList( $query, $limitstart, $limit )
	{
		// get original list
		$list = parent::_getList( $query, $limitstart, $limit );
		JLoader::import('components.com_jmylife.helpers.story', JPATH_ADMINISTRATOR, '');
		$story = JmylifeStoryHelper::getInstance();
		return $story->prepareList( $list, 'item' );
	}

	/**
	 * gets comment list (override for long word handling)
	 * @return object list
	 * @since 1.0.5
	 */
	function _jmlGetCommentList( $query, $limitstart, $limit )
	{
		$list = parent::_getList( $query, $limitstart, $limit );
		JLoader::import('components.com_jmylife.helpers.comment', JPATH_ADMINISTRATOR, '');
		$comment = JmylifeCommentHelper::getInstance();
		return $comment->prepareList( $list, 'item' );
	}

	/**
	 * builds category query
	 * @return string
	 *
	 */
	function _buildCategoryQuery()
	{
		$query = 'SELECT * FROM `#__jmylife_categories` WHERE `published` = 1';
		// all done!
		return $query;
	}

	/**
	 * Gets the item data
	 * @return stdClass object of listings
	 *
	 * @todo use Joomla Tables instead of simple queries
	 */
	function getData() {
		// if data hasn't already been obtained, load it
		if (empty($this->_data)) {
			JLoader::import('components.com_jmylife.helpers.story', JPATH_ADMINISTRATOR, '');
			$story = JmylifeStoryHelper::getInstance();
			$query = $story->buildQuery( JRequest::get() );
			$data = $this->_jmlGetList( $query, 0, 1 );
			$this->_data = $data[0];
		}
		return $this->_data;
	}

	/**
	 * Gets the comment data
	 * @return stdClass object of listings
	 *
	 * @todo use Joomla Tables instead of simple queries
	 */
	function getComments()
	{
		$_JMLConfig = JmylifeConfiguration::getInstance();
		// if data hasn't already been obtained, load it
		if( empty( $this->_comments ) )
		{
			JLoader::import('components.com_jmylife.helpers.comment', JPATH_ADMINISTRATOR, '');
			$comment = JmylifeCommentHelper::getInstance();
			$query = $comment->buildQuery( JRequest::getInt( 'id' ) );
			// since 1.0.9 pagination is optional, so no limitstart/limit if pagination is off
			$_pages = $_JMLConfig->getInt( 'comment_pagination', 1 );
			$_start = ( $_pages ? $this->getState( 'limitstart' ) : 0 );
			$_limit = ( $_pages ? $this->getState( 'limit' ) : null );
			$this->_comments = $this->_jmlGetCommentList( $query, $_start, $_limit );
		}
		return $this->_comments;
	}

	/**
	 * Gets the latest comment data
	 * @return stdClass object of listings
	 */
	function getLatestComments()
	{
		$_JMLConfig = JmylifeConfiguration::getInstance();
		// if data hasn't already been obtained, load it
		if( empty( $this->_comments ) )
		{
			JLoader::import('components.com_jmylife.helpers.comment', JPATH_ADMINISTRATOR, '');
			$comment = JmylifeCommentHelper::getInstance();
			$query = $comment->buildQuery( JRequest::getInt( 'id' ), 1, true );
			// since 1.0.9 pagination is optional, so no limitstart/limit if pagination is off
			$_pages = $_JMLConfig->getInt( 'comment_pagination', 1 );
			$_start = ( $_pages ? $this->getState( 'limitstart' ) : 0 );
			$_limit = ( $_pages ? $this->getState( 'limit' ) : null );
			$this->_comments = $this->_jmlGetCommentList( $query, $_start, $_limit );
		}
		return $this->_comments;
	}

	/**
	 * Gets the total amount of listings
	 * @return int
	 */
	function getTotal()
	{
		// Load the content if it doesn't already exist
		if( empty( $this->_total ) )
		{
			JLoader::import('components.com_jmylife.helpers.comment', JPATH_ADMINISTRATOR, '');
			$comment = JmylifeCommentHelper::getInstance();
			$query = $comment->buildQuery( JRequest::getInt( 'id' ) );
			$this->_total = $this->_getListCount( $query );
		}
		return $this->_total;
	}

	/**
	 * Gets the listings pagination
	 * @return JPagination object
	 */
	function getPagination()
	{
		// Load the content if it doesn't already exist
		if( empty( $this->_pagination ) )
		{
			jimport( 'joomla.html.pagination' );
			$total = @$this->getTotal();
			$this->_pagination = new JPagination( $total, $this->getState( 'limitstart' ), $this->getState( 'limit' ) );
		}
		return $this->_pagination;
	}

	/**
	 * Gets the categories as a list
	 * @return JPagination object
	 */
	function getCategories()
	{
		// Load the content if it doesn't already exist
		if( empty( $this->_categories ) )
		{
			$query = $this->_buildCategoryQuery();
			$this->_categories = $this->_getList( $query, 0, 99999 );
		}
		return $this->_categories;
	}

	/**
	 * Gets html for option editing
	 * @return html string
	 */
	function getOptions() {
		if (empty($this->_options)) {
			$item =& $this->getData();
			$this->_options = '';
			$user = JFactory::getUser();
			$cfg = JmylifeConfiguration::getInstance();
			if (!$cfg->getBool('edit_options')) {
				return $this->_options;
			}
			if (in_array($user->gid, array(25, $cfg->getInt('frontend_edit_group')))) {
				JLoader::import('components.com_jmylife.helpers.html', JPATH_ADMINISTRATOR, '');
				$html = JmylifeHtmlHelper::getInstance();
				$template = '<div class="jmlFormItem">%s</div>';
				$this->_options .= sprintf($template, $html->boolRadio('published', 'COM_JMYLIFE_CORE_PUBLISHED', $item->published));
				$this->_options .= sprintf($template, $html->boolRadio('allow_comments', 'COM_JMYLIFE_STORY_ENABLE_COMMENTS', $item->allow_comments));
				$this->_options .= sprintf($template, $html->boolRadio('allow_votes', 'COM_JMYLIFE_STORY_ENABLE_VOTING', $item->allow_votes));
			}
		}
		return $this->_options;
	}

	/**
	 * Gets the hidden inputs for the form
	 * @return string
	 */
	function getFields()
	{
		global $option, $view;
		// hack for now, fix later...
		$fields = '<input type="hidden" name="option" value="'.htmlentities($option).'" />'
		        . '<input type="hidden" name="view"   value="'.htmlentities($view).'" />'
		        ;
		return $fields;
	}
}